==> openshift-model-operatorhub-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterServiceVersionFluent<A extends ClusterServiceVersionFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ClusterServiceVersionFluent.MetadataNested<A> editMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionSpec getSpec();
    public ClusterServiceVersionSpec buildSpec();
    public A withSpec(ClusterServiceVersionSpec spec);
    public Boolean hasSpec();
    public ClusterServiceVersionFluent.SpecNested<A> withNewSpec();
    public ClusterServiceVersionFluent.SpecNested<A> withNewSpecLike(ClusterServiceVersionSpec item);
    public ClusterServiceVersionFluent.SpecNested<A> editSpec();
    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpec();
    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpecLike(ClusterServiceVersionSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionStatus getStatus();
    public ClusterServiceVersionStatus buildStatus();
    public A withStatus(ClusterServiceVersionStatus status);
    public Boolean hasStatus();
    public ClusterServiceVersionFluent.StatusNested<A> withNewStatus();
    public ClusterServiceVersionFluent.StatusNested<A> withNewStatusLike(ClusterServiceVersionStatus item);
    public ClusterServiceVersionFluent.StatusNested<A> editStatus();
    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatus();
    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatusLike(ClusterServiceVersionStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ClusterServiceVersionFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterServiceVersionSpecFluent<ClusterServiceVersionFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterServiceVersionStatusFluent<ClusterServiceVersionFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterServiceVersionFluent<A extends ClusterServiceVersionFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ClusterServiceVersionFluent.MetadataNested<A> editMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadata();
    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionSpec getSpec();
    public ClusterServiceVersionSpec buildSpec();
    public A withSpec(ClusterServiceVersionSpec spec);
    public Boolean hasSpec();
    public ClusterServiceVersionFluent.SpecNested<A> withNewSpec();
    public ClusterServiceVersionFluent.SpecNested<A> withNewSpecLike(ClusterServiceVersionSpec item);
    public ClusterServiceVersionFluent.SpecNested<A> editSpec();
    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpec();
    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpecLike(ClusterServiceVersionSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionStatus getStatus();
    public ClusterServiceVersionStatus buildStatus();
    public A withStatus(ClusterServiceVersionStatus status);
    public Boolean hasStatus();
    public ClusterServiceVersionFluent.StatusNested<A> withNewStatus();
    public ClusterServiceVersionFluent.StatusNested<A> withNewStatusLike(ClusterServiceVersionStatus item);
    public ClusterServiceVersionFluent.StatusNested<A> editStatus();
    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatus();
    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatusLike(ClusterServiceVersionStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ClusterServiceVersionFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterServiceVersionSpecFluent<ClusterServiceVersionFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterServiceVersionStatusFluent<ClusterServiceVersionFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
